Module: JekyllReact
- Defined in:
- lib/jekyll_react/render.rb,
lib/jekyll_react/page-data.rb
Overview
READ: Copied from official Jekyll repositories the only purpose of this is to render liquid in a page that is being converted to JSON in order to enable the ability to use Liquid in a page that will be dynamically rendered later